
# Type: sequence variant_has gene




URI: [biolink:sequence_variant_has_gene](https://w3id.org/biolink/vocab/sequence_variant_has_gene)


## Domain and Range

[SequenceVariant](SequenceVariant.md) ->  <sub>0..*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [has gene](has_gene.md)

## Children


## Used by

 * [SequenceVariant](SequenceVariant.md)
